@@ -5,7 +5,7 @@ from itertools import combinations
 import numpy as np
 import pandas as pd
 import networkx as nx
-from tqdm import tqdm
+from tqdm.auto import tqdm
 from joblib import Parallel, delayed
 from sklearn.metrics import (
     mutual_info_score,
