@@ -1,13 +1,20 @@
 from pgmpy.estimators.base import BaseEstimator, ParameterEstimator, StructureEstimator
 from pgmpy.estimators.MLE import MaximumLikelihoodEstimator
 from pgmpy.estimators.BayesianEstimator import BayesianEstimator
-from pgmpy.estimators.StructureScore import StructureScore, K2Score, BDeuScore, BicScore
+from pgmpy.estimators.StructureScore import (
+    StructureScore,
+    K2Score,
+    BDeuScore,
+    BDsScore,
+    BicScore,
+)
 from pgmpy.estimators.ExhaustiveSearch import ExhaustiveSearch
 from pgmpy.estimators.HillClimbSearch import HillClimbSearch
 from pgmpy.estimators.TreeSearch import TreeSearch
 from pgmpy.estimators.SEMEstimator import SEMEstimator, IVEstimator
 from pgmpy.estimators.ScoreCache import ScoreCache
 from pgmpy.estimators.MmhcEstimator import MmhcEstimator
+from pgmpy.estimators.EM import ExpectationMaximization
 from pgmpy.estimators.PC import PC
 
 __all__ = [
@@ -22,10 +29,12 @@ __all__ = [
     "StructureScore",
     "K2Score",
     "BDeuScore",
+    "BDsScore",
     "BicScore",
     "ScoreCache",
     "SEMEstimator",
     "IVEstimator",
     "MmhcEstimator",
     "PC",
+    "ExpectationMaximization",
 ]
