@@ -4,14 +4,14 @@ import numpy as np
 import numpy.testing as np_test
 import pandas as pd
 
-from pgmpy.models.BayesianModel import BayesianModel
+from pgmpy.models import BayesianNetwork
 from pgmpy.factors.discrete import TabularCPD
 from pgmpy.inference.CausalInference import CausalInference
 
 
 class TestCausalGraphMethods(unittest.TestCase):
     def setUp(self):
-        self.game = BayesianModel(
+        self.game = BayesianNetwork(
             [("A", "X"), ("A", "B"), ("C", "B"), ("C", "Y"), ("X", "Y"), ("B", "X")]
         )
         self.inference = CausalInference(self.game)
@@ -30,7 +30,7 @@ class TestAdjustmentSet(unittest.TestCase):
     def setUp(self):
         # Model example taken from Constructing Separators and Adjustment Sets
         # in Ancestral Graphs UAI 2014.
-        self.model = BayesianModel(
+        self.model = BayesianNetwork(
             [("x1", "y1"), ("x1", "z1"), ("z1", "z2"), ("z2", "x2"), ("y2", "z2")]
         )
         self.infer = CausalInference(self.model)
@@ -79,13 +79,13 @@ class TestAdjustmentSet(unittest.TestCase):
 
     def test_get_minimal_adjustment_set(self):
         # Without latent variables
-        dag1 = BayesianModel([("X", "Y"), ("Z", "X"), ("Z", "Y")])
+        dag1 = BayesianNetwork([("X", "Y"), ("Z", "X"), ("Z", "Y")])
         infer = CausalInference(dag1)
         adj_set = infer.get_minimal_adjustment_set(X="X", Y="Y")
         self.assertEqual(adj_set, {"Z"})
 
         # M graph
-        dag2 = BayesianModel(
+        dag2 = BayesianNetwork(
             [("X", "Y"), ("Z1", "X"), ("Z1", "Z3"), ("Z2", "Z3"), ("Z2", "Y")]
         )
         infer = CausalInference(dag2)
@@ -93,13 +93,13 @@ class TestAdjustmentSet(unittest.TestCase):
         self.assertEqual(adj_set, set())
 
         # With latents
-        dag_lat1 = BayesianModel([("X", "Y"), ("Z", "X"), ("Z", "Y")], latents={"Z"})
+        dag_lat1 = BayesianNetwork([("X", "Y"), ("Z", "X"), ("Z", "Y")], latents={"Z"})
         infer = CausalInference(dag_lat1)
         adj_set = infer.get_minimal_adjustment_set(X="X", Y="Y")
         self.assertIsNone(adj_set)
 
         # Pearl's Simpson machine
-        dag_lat2 = BayesianModel(
+        dag_lat2 = BayesianNetwork(
             [
                 ("X", "Y"),
                 ("Z1", "U"),
@@ -123,14 +123,14 @@ class TestBackdoorPaths(unittest.TestCase):
     """
 
     def test_game1(self):
-        game1 = BayesianModel([("X", "A"), ("A", "Y"), ("A", "B")])
+        game1 = BayesianNetwork([("X", "A"), ("A", "Y"), ("A", "B")])
         inference = CausalInference(game1)
         self.assertTrue(inference.is_valid_backdoor_adjustment_set("X", "Y"))
         deconfounders = inference.get_all_backdoor_adjustment_sets("X", "Y")
         self.assertEqual(deconfounders, frozenset())
 
     def test_game2(self):
-        game2 = BayesianModel(
+        game2 = BayesianNetwork(
             [
                 ("X", "E"),
                 ("E", "Y"),
@@ -147,7 +147,7 @@ class TestBackdoorPaths(unittest.TestCase):
         self.assertEqual(deconfounders, frozenset())
 
     def test_game3(self):
-        game3 = BayesianModel(
+        game3 = BayesianNetwork(
             [("X", "Y"), ("X", "A"), ("B", "A"), ("B", "Y"), ("B", "X")]
         )
         inference = CausalInference(game3)
@@ -156,14 +156,14 @@ class TestBackdoorPaths(unittest.TestCase):
         self.assertEqual(deconfounders, frozenset({frozenset({"B"})}))
 
     def test_game4(self):
-        game4 = BayesianModel([("A", "X"), ("A", "B"), ("C", "B"), ("C", "Y")])
+        game4 = BayesianNetwork([("A", "X"), ("A", "B"), ("C", "B"), ("C", "Y")])
         inference = CausalInference(game4)
         self.assertTrue(inference.is_valid_backdoor_adjustment_set("X", "Y"))
         deconfounders = inference.get_all_backdoor_adjustment_sets("X", "Y")
         self.assertEqual(deconfounders, frozenset())
 
     def test_game5(self):
-        game5 = BayesianModel(
+        game5 = BayesianNetwork(
             [("A", "X"), ("A", "B"), ("C", "B"), ("C", "Y"), ("X", "Y"), ("B", "X")]
         )
         inference = CausalInference(game5)
@@ -174,7 +174,7 @@ class TestBackdoorPaths(unittest.TestCase):
         )
 
     def test_game6(self):
-        game6 = BayesianModel(
+        game6 = BayesianNetwork(
             [
                 ("X", "F"),
                 ("C", "X"),
@@ -212,8 +212,11 @@ class TestDoQuery(unittest.TestCase):
         self.example_model = self.get_example_model()
         self.example_infer = CausalInference(self.example_model)
 
+        self.iv_model = self.get_iv_model()
+        self.iv_infer = CausalInference(self.iv_model)
+
     def get_simpson_model(self):
-        simpson_model = BayesianModel([("S", "T"), ("T", "C"), ("S", "C")])
+        simpson_model = BayesianNetwork([("S", "T"), ("T", "C"), ("S", "C")])
         cpd_s = TabularCPD(
             variable="S",
             variable_card=2,
@@ -242,7 +245,9 @@ class TestDoQuery(unittest.TestCase):
 
     def get_example_model(self):
         # Model structure: Z -> X -> Y; Z -> W -> Y
-        example_model = BayesianModel([("X", "Y"), ("Z", "X"), ("Z", "W"), ("W", "Y")])
+        example_model = BayesianNetwork(
+            [("X", "Y"), ("Z", "X"), ("Z", "W"), ("W", "Y")]
+        )
         cpd_z = TabularCPD(variable="Z", variable_card=2, values=[[0.2], [0.8]])
 
         cpd_x = TabularCPD(
@@ -273,8 +278,35 @@ class TestDoQuery(unittest.TestCase):
 
         return example_model
 
+    def get_iv_model(self):
+        # Model structure: Z -> X -> Y; X <- U -> Y
+        example_model = BayesianNetwork(
+            [("Z", "X"), ("X", "Y"), ("U", "X"), ("U", "Y")]
+        )
+        cpd_z = TabularCPD(variable="Z", variable_card=2, values=[[0.2], [0.8]])
+        cpd_u = TabularCPD(variable="U", variable_card=2, values=[[0.7], [0.3]])
+        cpd_x = TabularCPD(
+            variable="X",
+            variable_card=2,
+            values=[[0.1, 0.3, 0.2, 0.9], [0.9, 0.7, 0.8, 0.1]],
+            evidence=["U", "Z"],
+            evidence_card=[2, 2],
+        )
+        cpd_y = TabularCPD(
+            variable="Y",
+            variable_card=2,
+            values=[[0.5, 0.8, 0.2, 0.7], [0.5, 0.2, 0.8, 0.3]],
+            evidence=["U", "X"],
+            evidence_card=[2, 2],
+        )
+
+        example_model.add_cpds(cpd_z, cpd_u, cpd_x, cpd_y)
+
+        return example_model
+
     def test_query(self):
         for algo in ["ve", "bp"]:
+            # Simpson model queries
             query_nodo1 = self.simp_infer.query(
                 variables=["C"], do=None, evidence={"T": 1}, inference_algo=algo
             )
@@ -298,8 +330,25 @@ class TestDoQuery(unittest.TestCase):
             query3 = self.simp_infer.query(["C"], adjustment_set=["S"])
             np_test.assert_array_almost_equal(query3.values, np.array([0.55, 0.45]))
 
-    def test_adjustment_query(self):
+            # IV model queries
+            query_nodo1 = self.iv_infer.query(["Z"], do=None, inference_algo=algo)
+            np_test.assert_array_almost_equal(query_nodo1.values, np.array([0.2, 0.8]))
 
+            query_nodo2 = self.iv_infer.query(["X"], do=None, evidence={"Z": 1})
+            np_test.assert_array_almost_equal(
+                query_nodo2.values, np.array([0.48, 0.52])
+            )
+
+            query1 = self.iv_infer.query(["X"], do={"Z": 1})
+            np_test.assert_array_almost_equal(query1.values, np.array([0.48, 0.52]))
+
+            query2 = self.iv_infer.query(["Y"], do={"X": 1})
+            np_test.assert_array_almost_equal(query2.values, np.array([0.77, 0.23]))
+
+            query3 = self.iv_infer.query(["Y"], do={"X": 1}, adjustment_set={"U"})
+            np_test.assert_array_almost_equal(query3.values, np.array([0.77, 0.23]))
+
+    def test_adjustment_query(self):
         for algo in ["ve", "bp"]:
             # Test adjustment with do operation.
             query1 = self.example_infer.query(
@@ -322,6 +371,58 @@ class TestDoQuery(unittest.TestCase):
             query5 = self.example_infer.query(["Y"], adjustment_set=["W", "Z"])
             np_test.assert_array_almost_equal(query5.values, np.array([0.62, 0.38]))
 
+    def test_issue_1459(self):
+        bn = BayesianNetwork([("X", "Y"), ("W", "X"), ("W", "Y")])
+        cpd_w = TabularCPD(variable="W", variable_card=2, values=[[0.7], [0.3]])
+        cpd_x = TabularCPD(
+            variable="X",
+            variable_card=2,
+            values=[[0.7, 0.4], [0.3, 0.6]],
+            evidence=["W"],
+            evidence_card=[2],
+        )
+        cpd_y = TabularCPD(
+            variable="Y",
+            variable_card=2,
+            values=[[0.7, 0.7, 0.5, 0.1], [0.3, 0.3, 0.5, 0.9]],
+            evidence=["W", "X"],
+            evidence_card=[2, 2],
+        )
+
+        bn.add_cpds(cpd_w, cpd_x, cpd_y)
+        causal_infer = CausalInference(bn)
+        query = causal_infer.query(["Y"], do={"X": 1}, evidence={"W": 1})
+        np_test.assert_array_almost_equal(query.values, np.array([0.1, 0.9]))
+
+        # A slight modified version of the above model where only some of the adjustment
+        # set variables are in evidence.
+        bn = BayesianNetwork(
+            [("X", "Y"), ("W1", "X"), ("W1", "Y"), ("W2", "X"), ("W2", "Y")]
+        )
+        cpd_w1 = TabularCPD(variable="W1", variable_card=2, values=[[0.7], [0.3]])
+        cpd_w2 = TabularCPD(variable="W2", variable_card=2, values=[[0.3], [0.7]])
+        cpd_x = TabularCPD(
+            variable="X",
+            variable_card=2,
+            values=[[0.7, 0.4, 0.3, 0.8], [0.3, 0.6, 0.7, 0.2]],
+            evidence=["W1", "W2"],
+            evidence_card=[2, 2],
+        )
+        cpd_y = TabularCPD(
+            variable="Y",
+            variable_card=2,
+            values=[
+                [0.7, 0.7, 0.5, 0.1, 0.9, 0.2, 0.4, 0.6],
+                [0.3, 0.3, 0.5, 0.9, 0.1, 0.8, 0.6, 0.4],
+            ],
+            evidence=["W1", "W2", "X"],
+            evidence_card=[2, 2, 2],
+        )
+        bn.add_cpds(cpd_w1, cpd_w2, cpd_x, cpd_y)
+        causal_infer = CausalInference(bn)
+        query = causal_infer.query(["Y"], do={"X": 1}, evidence={"W1": 1})
+        np_test.assert_array_almost_equal(query.values, np.array([0.48, 0.52]))
+
     def test_query_error(self):
         self.assertRaises(ValueError, self.simp_infer.query, variables="C", do={"T": 1})
         self.assertRaises(
@@ -346,7 +447,7 @@ class TestDoQuery(unittest.TestCase):
 
 class TestEstimator(unittest.TestCase):
     def test_create_estimator(self):
-        game1 = BayesianModel([("X", "A"), ("A", "Y"), ("A", "B")])
+        game1 = BayesianNetwork([("X", "A"), ("A", "Y"), ("A", "B")])
         data = pd.DataFrame(
             np.random.randint(2, size=(1000, 4)), columns=["X", "A", "B", "Y"]
         )
