@@ -20,6 +20,8 @@ from pgmpy.estimators import (
     MaximumLikelihoodEstimator,
 )
 from pgmpy.base import DAG
+from pgmpy.utils import get_example_model
+from pgmpy.sampling import BayesianModelSampling
 
 
 class TestBaseModelCreation(unittest.TestCase):
@@ -688,6 +690,23 @@ class TestBayesianModelFitPredict(unittest.TestCase):
             self.model2.get_cpds("B"), TabularCPD("B", 2, [[11.0 / 15], [4.0 / 15]])
         )
 
+    def test_fit_update(self):
+        model = get_example_model("asia")
+        model_copy = model.copy()
+        data = BayesianModelSampling(model).forward_sample(int(1e3))
+        model.fit_update(data, n_prev_samples=int(1e3))
+        for var in model.nodes():
+            self.assertTrue(
+                model_copy.get_cpds(var).__eq__(model.get_cpds(var), atol=0.1)
+            )
+
+        model = model_copy.copy()
+        model.fit_update(data)
+        for var in model.nodes():
+            self.assertTrue(
+                model_copy.get_cpds(var).__eq__(model.get_cpds(var), atol=0.1)
+            )
+
     def test_fit_missing_data(self):
         self.model2.fit(
             self.data2, state_names={"C": [0, 1]}, complete_samples_only=False
@@ -1216,6 +1235,12 @@ class TestBayesianModelFitPredict(unittest.TestCase):
                 np.array([[[0.3, 0.4], [0.7, 0.8]], [[0.7, 0.6], [0.3, 0.2]]]),
             )
 
+    def test_simulate(self):
+        asia = get_example_model("asia")
+        n_samples = int(1e3)
+        samples = asia.simulate(n_samples=n_samples)
+        self.assertEqual(samples.shape[0], n_samples)
+
     def tearDown(self):
         del self.model_connected
         del self.model_disconnected
