@@ -1,16 +1,19 @@
 import unittest
 
 from mock import MagicMock, patch
+import numpy as np
 
 from pgmpy.factors.discrete import DiscreteFactor, TabularCPD, State
-from pgmpy.models import BayesianModel, MarkovModel
+from pgmpy.models import BayesianNetwork, MarkovNetwork
+from pgmpy.models import DynamicBayesianNetwork as DBN
 from pgmpy.sampling import BayesianModelSampling, GibbsSampling
+from pgmpy.inference import VariableElimination, DBNInference
 
 
 class TestBayesianModelSampling(unittest.TestCase):
     def setUp(self):
         # Bayesian Model without state names
-        self.bayesian_model = BayesianModel(
+        self.bayesian_model = BayesianNetwork(
             [("A", "J"), ("R", "J"), ("J", "Q"), ("J", "L"), ("G", "L")]
         )
         cpd_a = TabularCPD("A", 2, [[0.2], [0.8]])
@@ -25,8 +28,12 @@ class TestBayesianModelSampling(unittest.TestCase):
         cpd_g = TabularCPD("G", 2, [[0.6], [0.4]])
         self.bayesian_model.add_cpds(cpd_a, cpd_g, cpd_j, cpd_l, cpd_q, cpd_r)
         self.sampling_inference = BayesianModelSampling(self.bayesian_model)
+        self.forward_marginals = VariableElimination(self.bayesian_model).query(
+            self.bayesian_model.nodes(), joint=False
+        )
+
         # Bayesian Model without state names and with latent variables
-        self.bayesian_model_lat = BayesianModel(
+        self.bayesian_model_lat = BayesianNetwork(
             [("A", "J"), ("R", "J"), ("J", "Q"), ("J", "L"), ("G", "L")],
             latents=["R", "Q"],
         )
@@ -44,7 +51,7 @@ class TestBayesianModelSampling(unittest.TestCase):
         self.sampling_inference_lat = BayesianModelSampling(self.bayesian_model_lat)
 
         # Bayesian Model with state names
-        self.bayesian_model_names = BayesianModel(
+        self.bayesian_model_names = BayesianNetwork(
             [("A", "J"), ("R", "J"), ("J", "Q"), ("J", "L"), ("G", "L")]
         )
         cpd_a_names = TabularCPD(
@@ -87,7 +94,7 @@ class TestBayesianModelSampling(unittest.TestCase):
         self.sampling_inference_names = BayesianModelSampling(self.bayesian_model_names)
 
         # Bayesian Model with state names and with latent variables
-        self.bayesian_model_names_lat = BayesianModel(
+        self.bayesian_model_names_lat = BayesianNetwork(
             [("A", "J"), ("R", "J"), ("J", "Q"), ("J", "L"), ("G", "L")],
             latents=["R", "Q"],
         )
@@ -132,7 +139,7 @@ class TestBayesianModelSampling(unittest.TestCase):
             self.bayesian_model_names_lat
         )
 
-        self.markov_model = MarkovModel()
+        self.markov_model = MarkovNetwork()
 
     def test_init(self):
         with self.assertRaises(TypeError):
@@ -140,8 +147,8 @@ class TestBayesianModelSampling(unittest.TestCase):
 
     def test_forward_sample(self):
         # Test without state names
-        sample = self.sampling_inference.forward_sample(25)
-        self.assertEqual(len(sample), 25)
+        sample = self.sampling_inference.forward_sample(int(1e5))
+        self.assertEqual(len(sample), int(1e5))
         self.assertEqual(len(sample.columns), 6)
         self.assertIn("A", sample.columns)
         self.assertIn("J", sample.columns)
@@ -156,6 +163,19 @@ class TestBayesianModelSampling(unittest.TestCase):
         self.assertTrue(set(sample.G).issubset({0, 1}))
         self.assertTrue(set(sample.L).issubset({0, 1}))
 
+        # Test that the marginal distribution of samples is same as the model
+        sample_marginals = {
+            node: sample[node].value_counts() / sample.shape[0]
+            for node in self.bayesian_model.nodes()
+        }
+
+        for node in self.bayesian_model.nodes():
+            for state in [0, 1]:
+                self.assertEqual(
+                    round(self.forward_marginals[node].get_value(**{node: state}), 1),
+                    round(sample_marginals[node].loc[state], 1),
+                )
+
         # Test without state names and with latents
         sample = self.sampling_inference_lat.forward_sample(25, include_latents=True)
         self.assertEqual(len(sample), 25)
@@ -217,9 +237,9 @@ class TestBayesianModelSampling(unittest.TestCase):
         # Test without state names
         sample = self.sampling_inference.rejection_sample()
         sample = self.sampling_inference.rejection_sample(
-            [State("A", 1), State("J", 1), State("R", 1)], 25
+            [State("A", 1), State("J", 1), State("R", 1)], int(1e5)
         )
-        self.assertEqual(len(sample), 25)
+        self.assertEqual(len(sample), int(1e5))
         self.assertEqual(len(sample.columns), 6)
         self.assertEqual(set(sample.columns), {"A", "J", "R", "Q", "G", "L"})
         self.assertTrue(set(sample.A).issubset({1}))
@@ -229,6 +249,23 @@ class TestBayesianModelSampling(unittest.TestCase):
         self.assertTrue(set(sample.G).issubset({0, 1}))
         self.assertTrue(set(sample.L).issubset({0, 1}))
 
+        # Test that the marginal distributions is the same in model and samples
+        self.rejection_marginals = VariableElimination(self.bayesian_model).query(
+            ["Q", "G", "L"], evidence={"A": 1, "J": 1, "R": 1}, joint=False
+        )
+
+        sample_marginals = {
+            node: sample[node].value_counts() / sample.shape[0]
+            for node in ["Q", "G", "L"]
+        }
+
+        for node in ["Q", "G", "L"]:
+            for state in [0, 1]:
+                self.assertEqual(
+                    round(self.rejection_marginals[node].get_value(**{node: state}), 1),
+                    round(sample_marginals[node].loc[state], 1),
+                )
+
         # Test without state names with latent variables
         sample = self.sampling_inference_lat.rejection_sample(
             [State("A", 1), State("J", 1), State("R", 1)], 25, include_latents=True
@@ -399,13 +436,13 @@ class TestGibbsSampling(unittest.TestCase):
             evidence=["diff", "intel"],
             evidence_card=[2, 2],
         )
-        self.bayesian_model = BayesianModel()
+        self.bayesian_model = BayesianNetwork()
         self.bayesian_model.add_nodes_from(["diff", "intel", "grade"])
         self.bayesian_model.add_edges_from([("diff", "grade"), ("intel", "grade")])
         self.bayesian_model.add_cpds(diff_cpd, intel_cpd, grade_cpd)
 
         # A test Markov model
-        self.markov_model = MarkovModel([("A", "B"), ("C", "B"), ("B", "D")])
+        self.markov_model = MarkovNetwork([("A", "B"), ("C", "B"), ("B", "D")])
         factor_ab = DiscreteFactor(["A", "B"], [2, 3], [1, 2, 3, 4, 5, 6])
         factor_cb = DiscreteFactor(
             ["C", "B"], [4, 3], [3, 1, 4, 5, 7, 8, 1, 3, 10, 4, 5, 6]
@@ -419,19 +456,9 @@ class TestGibbsSampling(unittest.TestCase):
         del self.bayesian_model
         del self.markov_model
 
-    @patch(
-        "pgmpy.sampling.GibbsSampling._get_kernel_from_bayesian_model", autospec=True
-    )
-    @patch("pgmpy.models.MarkovChain.__init__", autospec=True)
-    def test_init_bayesian_model(self, init, get_kernel):
-        model = MagicMock(spec_set=BayesianModel)
-        gibbs = GibbsSampling(model)
-        init.assert_called_once_with(gibbs)
-        get_kernel.assert_called_once_with(gibbs, model)
-
     @patch("pgmpy.sampling.GibbsSampling._get_kernel_from_markov_model", autospec=True)
     def test_init_markov_model(self, get_kernel):
-        model = MagicMock(spec_set=MarkovModel)
+        model = MagicMock(spec_set=MarkovNetwork)
         gibbs = GibbsSampling(model)
         get_kernel.assert_called_once_with(gibbs, model)
 
@@ -459,6 +486,24 @@ class TestGibbsSampling(unittest.TestCase):
         self.assertTrue(set(sample["intel"]).issubset({0, 1}))
         self.assertTrue(set(sample["grade"]).issubset({0, 1, 2}))
 
+    def test_sample_limit(self):
+        samples = self.gibbs.sample(size=int(1e4))
+        marginal_prob = VariableElimination(self.bayesian_model).query(
+            list(self.bayesian_model.nodes()), joint=False
+        )
+        sample_prob = {
+            node: samples.loc[:, node].value_counts() / 1e4
+            for node in self.bayesian_model.nodes()
+        }
+        for node in self.bayesian_model.nodes():
+            self.assertTrue(
+                np.allclose(
+                    sorted(marginal_prob[node].values),
+                    sorted(sample_prob[node].values),
+                    atol=0.05,
+                )
+            )
+
     @patch("pgmpy.sampling.GibbsSampling.random_state", autospec=True)
     def test_sample_less_arg(self, random_state):
         self.gibbs.state = None
